package cn.wisenergy.service.app.impl;

import cn.wisenergy.common.utils.R;
import cn.wisenergy.mapper.*;
import cn.wisenergy.model.app.*;
import cn.wisenergy.model.dto.UsersInfoDto;
import cn.wisenergy.model.vo.UserVo;
import cn.wisenergy.service.app.UserService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author 86187
 * @ Description: 用户接口实现
 * @ Author     : 86187
 * @ Date       : 2021/1/6 16:11
 */
@Service
@Slf4j
public class UserServiceImpl extends ServiceImpl<UsersMapper, Users> implements UserService {

    @Autowired
    private UsersMapper usersMapper;

    @Autowired
    private ActivesMapper activesMapper;

    @Autowired
    private UserRechargeMapper userRechargeMapper;

    @Autowired
    private UserWithdrawsMapper withdrawsMapper;

    @Autowired
    private UsdtOrderDetailsMapper orderDetailsMapper;

    @Override
    public Users getById(Long userId) {
        return null;
    }

    @Override
    public R<List<UserVo>> getLastUser(Long userId) {

        //用户id为空时，查询最顶级
        if (null == userId) {
            userId = 1L;
            Users users = usersMapper.getById(userId);
            UserVo userVo = new UserVo();
            userVo.setUserId(users.getId());
            userVo.setParentId(users.getParentId());
            userVo.setRealName(null);

            List<UserVo> list = new ArrayList<>();
            list.add(userVo);
            return R.ok(list);
        }

        //id不为空,查询当前用户的下一级
        Users user = usersMapper.getById(userId);
        List<UserVo> lastList = usersMapper.getLastUser(Integer.valueOf(user.getId().toString()));
        return R.ok(lastList);
    }

    @Override
    public R<UsersInfoDto> getByUserInfoById(Long userId) {
        if (null == userId) {
            return R.error("入参不能为空!");
        }

        UsersInfoDto userDto = new UsersInfoDto();

        //1、获取用户信息
        Users users = usersMapper.getById(userId);
        if (null != users) {
            userDto.setUserId(users.getId());
            userDto.setPhone(users.getPhone());
            userDto.setRank(users.getRank());
        }

        //2、获取用户身份信息
        Actives actives = activesMapper.getByUserId(userId);
        if (null != actives) {
            userDto.setIdNumber(actives.getIdNumber());
            userDto.setRealName(actives.getRealName());
        }

        //3、向下最深层级层级数
        double downLevel = usersMapper.getDownLevel(userId, userId);
        userDto.setBottom((int) downLevel);

        //4、伞下人员总和
        Integer total = usersMapper.getTotal(userId);
        if (null != total) {
            userDto.setTotalPeople(total);
        }

        //5、充值总额
        Double totalRecharge = userRechargeMapper.getTotalRecharge(userId);
        if (null != totalRecharge) {
            userDto.setTotalRecharge(String.valueOf(totalRecharge));
        }

        //6、提现总额
        Double totalWithdrawal = withdrawsMapper.getTotalWithdrawal(userId);
        if (null != totalWithdrawal) {
            userDto.setTotalWithdrawal(String.valueOf(totalWithdrawal));
        }

        //7、otc卖出总额
        Double buyTotal = orderDetailsMapper.getBuyTotal(userId);
        if (null != buyTotal) {
            userDto.setBuyTotal(String.valueOf(buyTotal));
        }

        //8、otc买入总额
        Double saleTotal = orderDetailsMapper.getSaleTotal(userId);
        if (null != saleTotal) {
            userDto.setSaleTotal(String.valueOf(saleTotal));
        }
        return R.ok(userDto);
    }

}
